Documentation
¶
Overview ¶
Package authhttp adapts authentication HTTP requests to the auth usecase.
Index ¶
- func Register(group *echo.Group, handler *Handler)
- type Handler
- func (h *Handler) ChangePassword(c *echo.Context) error
- func (h *Handler) Login(c *echo.Context) error
- func (h *Handler) Logout(c *echo.Context) error
- func (h *Handler) LogoutOthers(c *echo.Context) error
- func (h *Handler) Me(c *echo.Context) error
- func (h *Handler) SwitchRole(c *echo.Context) error
- func (h *Handler) UpdateProfile(c *echo.Context) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Handler ¶
type Handler struct {
// contains filtered or unexported fields
}
Handler adapts auth HTTP requests to the auth usecase.
func (*Handler) ChangePassword ¶
ChangePassword updates the current administrator password and revokes other login sessions for the same administrator.
func (*Handler) LogoutOthers ¶
LogoutOthers revokes the current administrator's other login sessions.
func (*Handler) SwitchRole ¶
SwitchRole changes the active role for the current administrator.
Click to show internal directories.
Click to hide internal directories.